@@ -28,17 +28,17 @@ class GdapsAdmin(ReadOnlyAdmin):
         "verbose_name",
         "version",
         "author",
-        "visible",
+        "hidden",
         "enabled",
         "category",
     ]
-    sortable_by = ["category", "visible", "enabled"]
+    sortable_by = ["category", "hidden", "enabled"]
 
     def get_readonly_fields(self, request, obj=None):
         return [
             name
             for name in super().get_readonly_fields(request, obj)
-            if not name in ["enabled", "visible"]
+            if not name in ["enabled", "hidden"]
         ]
 
 
