@@ -82,8 +82,10 @@ class Command(BaseCommand):
                 f"\nSuccessfully created plugin: {target_path}\n"
                 f"* Please edit '{target_path / 'setup.cfg'}' to your needs.\n"
                 f"* Install the plugin locally using 'pip install -e {self.plugin_path}/{settings.PROJECT_NAME}-{name}'\n"
+                f"  or with flit: 'flit install --symlink {self.plugin_path}/{settings.PROJECT_NAME}-{name}'\n"
                 f"  Or you can add the plugin directly to your INSTALLED_APPS if you want it bundled with your application.\n"
-                f"* Don't forget to call './manage.py syncplugins' to keep your DB in sync.\n"
+                f"* Don't forget to call './manage.py syncplugins' after installing a new plugin to keep "
+                f"your DB in sync.\n"
             )
         except Exception as e:
             logger.critical(f"There was an error with cookiecutter: \n {e}")
